@@ -1,7 +1,7 @@
 ## fix-up tolerances for use in TF computations
 fixUpTol <- function(tol, na.tol, small.tol, min.tol, f, env) {
     ## first missing tolerances
-    if(any(NA.TOL <- is.na(tol))) {
+    if(any(NA.TOL <- is.na(tol) | is.infinite(tol))) {
         tol[NA.TOL] <-
             switch(na.tol,
                    min = min(tol, na.rm = TRUE),
@@ -10,7 +10,6 @@ fixUpTol <- function(tol, na.tol, small.tol, min.tol, f, env) {
     }
     ## second, replace tol < min.tol
     if(!is.null(min.tol) && any(MIN.TOL <- tol < min.tol)) {
-        small.tol <- match.arg(small.tol)
         ## min.tol must be in or on extremesof range(env)
         if(min.tol < min(env) || min.tol > max(env))
             stop("'min.tol' must be >= min(env) and <= max(env)")
