@@ -4,8 +4,10 @@ plot.roc <- function(x,
                      prior = NULL,
                      show.stats = TRUE,
                      abline.col = "grey",
+                     abline.lty = "dashed",
                      inGroup.col = "red",
                      outGroup.col = "blue",
+                     lty = "solid",
                      caption = c("ROC curve",
                        "Dissimilarity profiles",
                      "TPF - FPF vs Dissimilarity",
@@ -34,12 +36,15 @@ plot.roc <- function(x,
         }
     }
     method <- attr(x, "method")
+    ## replicate lty if length 1
+    if(length(lty) == 1L)
+      lty <- rep(lty, 2)
     if(show[1]) {
         plot(x$roc[[group]]$FPE, x$roc[[group]]$TPF, type = "n",
              ylab = "TPF (sensitivity)",
              xlab = "1 - TNF (1 - specificity)")
         abline(0, 1, col = abline.col)
-        lines(x$roc[[group]]$FPE, x$roc[[group]]$TPF, ...)
+        lines(x$roc[[group]]$FPE, x$roc[[group]]$TPF, lty = lty[1L], ...)
         mtext(caption[1], side = 3, line = 1.7, font = 2)
         if(show.stats) {
             txt <- paste("AUC =", round(x$roc[[group]]$AUC, 3))
@@ -62,9 +67,9 @@ plot.roc <- function(x,
              xlab = paste("Dissimilarity (", attr(x, "method"), ")",
              sep = ""))
         abline(h = 0, col = abline.col)
-        lines(dens.in, col = inGroup.col)
-        lines(dens.out, col = outGroup.col)
-        abline(v = x$roc[[group]]$optimal, lty = "dotted",
+        lines(dens.in, col = inGroup.col, lty = lty[1L], ...)
+        lines(dens.out, col = outGroup.col, lty = lty[2L], ...)
+        abline(v = x$roc[[group]]$optimal, lty = abline.lty,
                col = abline.col)
         axis(side = 2)
         axis(side = 1)
@@ -72,9 +77,9 @@ plot.roc <- function(x,
         mtext(caption[2], side = 3, line = 1.7, font = 2)
         legend("topright", legend = c("Analogue", "Not Analogue"),
                col = c(inGroup.col, outGroup.col),
-               lty = "solid", lwd = 1,
+               lty = lty[c(1L,2L)],
                bty = "n", cex = 0.8,
-               inset = 0.01)
+               inset = 0.01, ...)
     }
     if(show[3]) {
         cutpoints <- unique(rev(x$roc[[group]]$roc.points))
@@ -84,8 +89,8 @@ plot.roc <- function(x,
              xlab = paste("Dissimilarity (", attr(x, "method"), ")",
              sep = ""))
         abline(h = 0, col = abline.col)
-        lines(cutpoints, roc.values)
-        abline(v = x$roc[[group]]$optimal, lty = "dotted",
+        lines(cutpoints, roc.values, lty = lty[1L], ...)
+        abline(v = x$roc[[group]]$optimal, lty = abline.lty,
                col = abline.col)
         mtext(caption[3], side = 3, line = 1.7, font = 2)
         box()
@@ -97,9 +102,9 @@ plot.roc <- function(x,
         plot(dissims, pos, type = "n", axes = FALSE, ylab = "LR (+)",
              xlab = paste("Dissimilarity (", attr(x, "method"), ")",
              sep = ""))
-        abline(v = x$roc[[group]]$optimal, lty = "dotted",
+        abline(v = x$roc[[group]]$optimal, lty = abline.lty,
                col = abline.col)
-        lines(dissims, pos, col = inGroup.col)
+        lines(dissims, pos, col = inGroup.col, lty = lty[1L], ...)
         axis(side = 1)
         axis(side = 2)
         usr <- par("usr")
@@ -108,22 +113,22 @@ plot.roc <- function(x,
                  min(neg[finite.vals])) * 0.04
         par(usr = c(usr[1:2], min(neg[finite.vals]) - rany,
             max(neg[finite.vals]) + rany))
-        lines(dissims, neg, col = outGroup.col)
+        lines(dissims, neg, col = outGroup.col, lty = lty[2L], ...)
         axis(side = 4)
         box()
         mtext(caption[4], side = 3, line = 1.7, font = 2)
         legend("topright", legend = c("LR (+)", "LR (-)"),
                col = c(inGroup.col, outGroup.col),
-               lty = "solid", lwd = 1,
+               lty = lty,
                bty = "n", cex = 0.8,
-               inset = 0.01)
+               inset = 0.01, ...)
     }
     if(show[5]) {
         plot(l.ratios, group = group,
              abline.col = abline.col, col = inGroup.col,
              ylab = "Pr (A+ | d)",
              xlab = paste("Dissimilarity (", attr(x, "method"), ")",
-             sep = ""))
+             sep = ""), lty = lty[1L], ...)
         ##mtext(caption[5], side = 3, line = 1.7, font = 2)
     }
     invisible()
